1.17.7 — Rucio 1.2 documentation

# 1.17.7

## General

### Features

- Core & Internals: Include archives in list_dataset_replicas(deep=True) #1375

### Enhancements

- Clients: Typos and other small fixes #1497
- Release management: Upgrade cryptography version due to CVE-2018-10903 #1480

### Bugs

- Documentation: readthedocs build fails due to pycurl #1390
- Release management: Restrict futures package to python 2.* setups #1486

## Clients

### Bugs

- Clients: –allow-tape option not available in rucio get #1484
- Clients: If policy section not available in client config, no exception should be raised #1485
- Clients: Upload with –no-register –pfn does not work #1487